@@ -336,6 +336,21 @@ class build_ext(_build_ext):
 
     def finalize_options(self):
         _build_ext.finalize_options(self)
+        import sys, os
+        from distutils import sysconfig
+        if (sys.platform.startswith('linux') and
+            sysconfig.get_config_var('Py_ENABLE_SHARED')):
+            try:
+                py_version = sysconfig.get_python_version()
+                bad_pylib_dir = os.path.join(sys.prefix, "lib",
+                                             "python" + py_version,
+                                             "config")
+                self.library_dirs.remove(bad_pylib_dir)
+            except ValueError:
+                pass
+            pylib_dir = os.path.join(sys.prefix, "lib")
+            self.library_dirs.append(pylib_dir)
+        
         self.set_undefined_options('build',
                                    ('petsc_dir',  'petsc_dir'),
                                    ('petsc_arch', 'petsc_arch'))
