@@ -4,9 +4,10 @@
 # Id: $Id$
 
 """
-PETSc Options Database
-======================
+Options Database
+================
 
+Simplify the use of command line, file options, etc.
 """
 
 # --------------------------------------------------------------------
@@ -15,7 +16,7 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
@@ -32,7 +33,7 @@ from petsc4py.lib import _petsc
 class Options(object):
 
     """
-    PETSc Options database.
+    Options database manager.
     """
 
     def __init__(self, prefix=None):
@@ -77,12 +78,20 @@ class Options(object):
     @staticmethod
     def setMonitor(monitor):
         """
+        Set an additional function to be called at every
+        method that modified the PETSc options database.
+
+        Signature for of `monitor`::
+        
+          def monitor(name, value):
+              # <monitor code>
         """
         _petsc.PetscOptionsMonitorSet(monitor)
     
     @staticmethod
     def cancelMonitor():
         """
+        Clear all registered monitors.
         """
         _petsc.PetscOptionsMonitorCancel()
 
