@@ -4,7 +4,7 @@
 # Id: $Id$
 
 """
-Nonlinear Solvers - SNES
+Nonlinear Solvers (SNES)
 ========================
 
 The Scalable Nonlinear Equations Solvers (SNES) component provides an
@@ -24,7 +24,7 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
@@ -50,7 +50,7 @@ class SNES(Object):
 
     class Type(object):
         """
-        SNES Types
+        SNES types.
 
         - `LS`: truncated Newton method with a line search,
         
@@ -297,7 +297,7 @@ class SNES(Object):
         return _petsc.SNESGetTolerances(self)
 
     def setTolerances(self,
-                      atol=None, rtol=None, stol=None,
+                      rtol=None, atol=None, stol=None,
                       max_it=None, max_funcs=None):
         """
         Set various parameters used in convergence tests.
@@ -307,6 +307,41 @@ class SNES(Object):
             if tol is None:
                 tolerances[i] = _petsc.PETSC_DEFAULT
         _petsc.SNESSetTolerances(self, *tolerances)
+
+    def getUseEW(self):
+        """
+        Get whether SNES is using alternative convergence test for the
+        iterative linear solvers within an inexact Newton method.
+        """
+        return bool(_petsc.SNESGetUseEW(self))
+        
+    def setUseEW(self, flag, *targs, **kargs):
+        """
+        Set alternative convergence test for the linear solvers within
+        an inexact Newton method.
+        """
+        _petsc.SNESSetUseEW(self, flag)
+        if targs or kargs:
+            self.setParamsEW(*targs,**kargs)
+        
+    def setParamsEW(self,
+                    version=None,
+                    rtol_0=None,
+                    rtol_max=None,
+                    gamma=None,
+                    alpha=None,
+                    alpha2=None,
+                    threshold=None):
+        """
+        Sets parameters for Eisenstat-Walker convergence criteria for
+        the linear solvers within an inexact Newton method.
+        """
+        parameters = [version, rtol_0, rtol_max,
+                      gamma, alpha, alpha2, threshold]
+        for i, param in enumerate(parameters):
+            if param is None:
+                parameters[i] = _petsc.PETSC_DEFAULT
+        _petsc.SNESSetParametersEW(self, *parameters)
         
     def setMonitor(self, monitor):
         """
@@ -320,36 +355,35 @@ class SNES(Object):
 
     clearMonitor = cancelMonitor
 
-
     def setConvergenceTest(self, convtest):
         """
         """
         _petsc.SNESSetConvergenceTest(self, convtest)
 
-
     def solve(self, x=None, b=None):
         """
         Solves a nonlinear system F(x) = b.
         """
         _petsc.SNESSolve(self, b, x)
 
+    def getConverged(self):
+        """
+        """
+        reason = _petsc.SNESGetConvergedReason(self)
+        reason_str = _petsc.SNESConvergedReasonString(reason)
+        return (reason, reason_str)
+
     def getConvergedReason(self):
         """
         """
         return _petsc.SNESGetConvergedReason(self)
 
-    def getConvergedReasonString(self):
+    def setConvergenceHistory(self, length=None, reset=True):
         """
         """
-        reason = _petsc.SNESGetConvergedReason(self)
-        return _petsc.SNESConvergedReasonString(reason)
-
-    def logConvergenceHistory(self, n=None, reset=True):
-        """
-        """
-        if n is None:
-            n = _petsc.PETSC_DECIDE
-        return _petsc.SNESLogConvergenceHistory(self, n, reset)
+        if length is None:
+            length = _petsc.PETSC_DECIDE
+        _petsc.SNESAllocConvHistory(self, length, reset)
 
     def getConvergenceHistory(self):
         """
@@ -384,22 +418,21 @@ class SNES(Object):
     appctx   = property(getApplicationContext, setApplicationContext)
     
     ksp      = property(getKSP, setKSP)
-    rsh      = property(getRhs, setRhs)
+    rhs      = property(getRhs, setRhs)
     solution = property(getSolution, setSolution)
 
-    abstol    = atol  = property(*_petsc.tolerance('atol',      0))
-    reltol    = rtol  = property(*_petsc.tolerance('rtol',      1))
+    reltol    = rtol  = property(*_petsc.tolerance('rtol',      0))
+    abstol    = atol  = property(*_petsc.tolerance('atol',      1))
     soltol    = stol  = property(*_petsc.tolerance('stol',      2))
     max_it    = maxit = property(*_petsc.tolerance('max_it',    3))
     max_funcs = maxf  = property(*_petsc.tolerance('max_funcs', 4))
     max_fails = property(getNumberUnsuccessfulSteps,
                          setMaximumUnsuccessfulSteps)
 
-    iternum    = property(getIterationNumber)
+    iternum    = its   = property(getIterationNumber)
+    funcnorm   = fnorm = property(getFunctionNorm)
     linear_its = property(getNumberLinearIterations)
-    funcnorm   = property(getFunctionNorm)
-    converged  = property(getConvergedReason)
-    convstr    = property(getConvergedReasonString)
+    converged  = property(getConverged)
     
 
 # --------------------------------------------------------------------
@@ -420,6 +453,8 @@ class SNESLS(SNES):
         CUBIC      = _petsc.LS_CUBIC
         #
         BASICNONORMS = NO_NORMS
+        NONORMS      = NO_NORMS
+        NONE         = BASIC
         
     def setLineSearch(self, ls):
         """
@@ -429,6 +464,15 @@ class SNESLS(SNES):
         
     def setLineSearchParams(self, alpha=None, maxsteps=None, steptol=None):
         """
+        Set the parameters associated with the line search routine in
+        the Newton-based method SNESLS.
+
+        :Parameters:
+          - `alpha`: the scalar such that
+            ``.5*f_{n+1} . f_{n+1} <= .5*f_n . f_n - alpha |f_n . J . f_n|``.
+          - `maxstep`: the maximum norm of the update vector.
+          - `steptol`: the minimum norm fraction of the original step
+            after scaling.
         """
         params = [alpha, maxsteps, steptol]
         for i, param in enumerate(params):
@@ -439,6 +483,15 @@ class SNESLS(SNES):
 
     def getLineSearchParams(self):
         """
+        Get the parameters associated with the line search
+        routine in the Newton-based method SNESLS.
+
+        :Returns:
+          - the scalar such that
+            ``.5*f_{n+1} . f_{n+1} <= .5*f_n . f_n - alpha |f_n . J . f_n|``.
+          - the maximum norm of the update vector.
+          - the minimum norm fraction of the original step
+            after scaling.
         """
         return _petsc.SNESLineSearchGetParams(self)
 
