@@ -4,7 +4,7 @@
 # Id: $Id$
 
 """
-PETSc Vectors
+Vectors (Vec)
 =============
 
 Vectors provide operations required for setting up and solving
@@ -19,7 +19,7 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
@@ -51,7 +51,7 @@ class Vec(Object):
 
     class Type(object):
         """
-        Vector types
+        Vec types.
         """
         SEQ    = _petsc.VECSEQ
         MPI    = _petsc.VECMPI
@@ -143,6 +143,12 @@ class Vec(Object):
         be set with `setSizes()` and the type can then be set with
         `setType()` (or perhaps `setFromOptions()`).
 
+        :Parameters:
+           - `comm`: MPI communicator to use (defaults to `COMM_WORLD`).
+
+       :Returns:
+         - the created vector.
+
         .. note:: If you never call `setSizes()` and `setType()` it
            will generate an error when you try to use the vector.
         """
@@ -158,7 +164,7 @@ class Vec(Object):
            - `comm`: MPI communicator to use (defaults to `COMM_SELF`,
              must be uniprocessor).
 
-       :Return:
+       :Returns:
          - the created sequential vector.
         """
         comm, n = _petsc.vecseq_size(comm, size, bsize)
@@ -173,12 +179,12 @@ class Vec(Object):
 
         :Parameters:
           - `size`: sequence ``(n, N)`` with local and global vector
-             length (any can be `DECIDE` to have calculated if other
-             is given) or integer indicating global size.
+            length (any can be `DECIDE` to have calculated if other
+            is given) or integer indicating global size.
           - `bsize`: vector block size (optional).
           - `comm`:  MPI communicator (defaults to `COMM_WORLD`).
 
-        :Return:
+        :Returns:
           - the created parallel vector.
         """
         comm, n, N = _petsc.vecmpi_size(comm, size, bsize)
@@ -193,15 +199,15 @@ class Vec(Object):
 
         :Parameters:
           - `size`: sequence ``(n, N)`` with local and global vector
-             length (any can be `DECIDE` to have calculated if other
-             is given) or integer indicating global size.
+            length (any can be `DECIDE` to have calculated if other
+            is given) or integer indicating global size.
           - `bsize`: vector block size (optional).
           - `comm`:  MPI communicator (defaults to `COMM_WORLD`).
 
        .. note:: Currently `VecShared` is available only on the SGI.
           Otherwise, this `Vec` is the same as `VecMPI`.
 
-        :Return:
+        :Returns:
           - the created shared vector.
           """
         comm, n, N = _petsc.vecmpi_size(comm, size, bsize)
@@ -215,27 +221,27 @@ class Vec(Object):
         Creates a parallel vector with ghost padding on each
         processor.
 
-       :Parameters:
+        :Parameters:
           - `size`: sequence ``(n, N)`` with local and global vector
-             length (any can be `DECIDE` to have calculated if other
-             is given) or integer indicating global size.
+            length (any can be `DECIDE` to have calculated if other is
+            given) or integer indicating global size.
           - `ghost`: ghost nodes.
           - `bsize`: vector block size (optional).
           - `comm`:  MPI communicator (defaults to `COMM_WORLD`).
 
-        :Return:
+        :Returns:
           - the created gosthed vector.
 
-        .. note:: `createGhost()` constructs the global vector
+        .. note:: `Vec.createGhost()` constructs the global vector
            representation (without ghost points as part of vector).
            To obtain de local vector representation, call
-           `VecGhost.getLocalForm()`.
+           `Vec.getLocalForm()`.
 
         .. hint:: 
 
-           If ``vg`` is a `VecGhost` instance, use the following to
-           update the ghost regions with correct values from the
-           owning process::
+           If ``vg`` is a vector instance with ghost values, use the
+           following to update the ghost regions with correct values
+           from the owning process::
 
               vg.ghostUpdate(InsertMode.INSERT,ScatterMode.FORWARD)
 
@@ -304,7 +310,7 @@ class Vec(Object):
     def getBlockSize(self):
         """
         Gets the blocksize for the vector, i.e. what is used for
-        `SetValuesBlocked()` and `SetValuesBlockedLocal()`.
+        `setValuesBlocked()` and `setValuesBlockedLocal()`.
 
         .. note:: All vectors obtained by `duplicate()` inherit the
            same block size.
@@ -635,10 +641,9 @@ class Vec(Object):
         :Parameters:
           - `indices`: array of indices.
           - `values`: array of values.
-          - `insert_mode`: either
-            + `INSERT_VALUES` to replaces existing entries with new
-              values.
-            + `ADD_VALUES` to add values to any existing entries.
+          - `insert_mode`: either `INSERT_VALUES` to replaces existing
+            entries with new values, or `ADD_VALUES` to add values to
+            any existing entries.
         """
         _petsc.VecSetValues(self, indices, values, insert_mode)
         
@@ -768,7 +773,8 @@ class Vec(Object):
         _petsc.VecGhostUpdateBegin(self, insert_mode, scatter_mode)
         _petsc.VecGhostUpdateEnd(self, insert_mode, scatter_mode)
 
-    option = property(fset=setOption)
+    option = property(fset=setOption,
+                      doc='Set an option or sequence of options')
     array = property(getArray, setArray)
     sizes = property(getSizes, setSizes)
     
@@ -813,9 +819,13 @@ class VecShared(Vec):
 
 class VecSieve(Vec):
     """
-    The parallel vector implementation based upon Sieve fields
+    The parallel vector implementation based upon Sieve fields.
     """
     __metaclass__ = Vec.Type(Vec.Type.SIEVE)
+    def __init__(self, *targs, **kwargs):
+        super(VecSieve, self).__init__(*targs, **kwargs)
+        #self.createSieve(*targs, **kwargs)
+        raise NotImplementedError
 
 # --------------------------------------------------------------------
 
@@ -877,12 +887,12 @@ class Scatter(Object):
         :Parameters:
           - `vec_from`: a vector that defines the shape (parallel data
             layout of the vector) of vectors from which we scatter.
-          - `is_from`: the indices of `vec_from` to scatter (or `None`
-             to scatter all values).
+          - `is_from`: the indices of `vec_from` to scatter (or
+            ``None`` to scatter all values).
           - `vec_to`: a vector that defines the shape (parallel data
             layout of the vector) of vectors to which we scatter.
           - `is_to`: the indices of `vec_to` to hold results (or
-             `None` to fill all values).
+            ``None`` to fill all values).
         """
         _petsc.VecScatterCreate(vec_from, is_from,
                                 vec_to,   is_to, self)
@@ -899,14 +909,14 @@ class Scatter(Object):
         Creates a scatter context that copies all vector values to
         each processor.
 
-        :Parameter: 
+        :Parameters: 
           - `vec`: input `VecMPI` instance.
 
-        :Return:
+        :Returns:
           - `Scatter` context.
           - `VecSeq` that is large enough to scatter into.
 
-        :Usage:
+        .. tip::
           # create scatter context and local vector
           scatter, vout = Scatter.toAll(vin)
           # scatter as many times as you need
@@ -931,7 +941,7 @@ class Scatter(Object):
           - `VecSeq` that is large enough to scatter into on
             processor 0 and of length zero on all other processors
 
-        :Usage:
+        .. tip::
           # create scatter context and local vector
           scatter, vout = Scatter.toZero(vin)
           # scatter as many times as you need
