@@ -7,7 +7,7 @@
 PETSc for Python
 ================
 
-This is an interface to PETSc libraries.
+This package is an interface to PETSc libraries.
 
 PETSc_ is a suite of data structures and routines for the scalable
 (parallel) solution of scientific applications modeled by partial
@@ -39,10 +39,10 @@ support for distributed arrays.
 
 __author__    = 'Lisandro Dalcin'
 __credits__   = "PETSc Team <petsc-maint@mcs.anl.gov>"
-__version__   = '0.7.0'
+__version__   = '0.7.1'
 __revision__  = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
@@ -51,16 +51,17 @@ def init(args=None, arch=None, comm=None):
     Initializes PETSc.
 
     :Parameters:
-      - 'args': Command-line arguments, usually the 'sys.argv' list.
-      - `arch`: Specific configuration to use.
+      - `args`: command-line arguments, usually the 'sys.argv' list.
+      - `arch`: specific configuration to use.
       - `comm`: MPI communicator to use as ``PETSC_COMM_WORLD``. The
         passed communicator **is not** duplicated, so it should not be
         freed before finalization. By default, ``PETSC_COMM_WORLD`` is
         ``MPI_COMM_WORLD``.
 
-    ..note::
-      ``PetscInitialize()`` will be actually called the first
-      time `PETSc` module is imported.
+    .. note:: This functions should be called only once, typically at
+      the beginning or any application. Function ``PetscInitialize()``
+      will be actually called the first time the `PETSc` module is
+      imported.
     """    
     import petsc4py.lib
     _petsc = petsc4py.lib.Import(arch)
@@ -130,7 +131,8 @@ def main(*args):
 
 if __name__ == '__main__':
     import sys
-    main(sys.argv[1:])
+    init(sys.argv)
+    main(*sys.argv[1:])
     del sys
 
 # --------------------------------------------------------------------
