@@ -157,10 +157,10 @@ class TestSNESBase(object):
         b = PETSc.Vec().createSeq(2)
         b.set(0)
         self.snes.setRhs(b)
-        self.snes.logConvergenceHistory()
+        self.snes.setConvergenceHistory()
         self.snes.solve()
         rh, ih = self.snes.getConvergenceHistory()
-        self.snes.logConvergenceHistory(0)
+        self.snes.setConvergenceHistory(0)
         rh, ih = self.snes.getConvergenceHistory()
         self.assertEqual(len(rh), 0)
         self.assertEqual(len(ih), 0)
